package com.muyu.javacomplier;

import lombok.extern.log4j.Log4j2;

import javax.tools.*;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Arrays;
@Log4j2
public class JavaCompilerDemo {

    public static void main(String[] args) {
        String sourceCode = "public class HelloWorld { public static void main(String[] args) { System.out.println(\"Hello, world!\"); } }";
        String fileName = "HelloWorld.java";
        try {
            // 将源代码写入文件
            writeToFile(fileName, sourceCode);

            // 获取Java编译器实例
            JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();

            // 设置编译参数
            DiagnosticCollector<JavaFileObject> diagnostics = new DiagnosticCollector<>();
            StandardJavaFileManager fileManager = compiler.getStandardFileManager(diagnostics, null, null);
            Iterable<? extends JavaFileObject> compilationUnits = fileManager.getJavaFileObjectsFromStrings(Arrays.asList(fileName));

            // 执行编译
            JavaCompiler.CompilationTask task = compiler.getTask(null, fileManager, diagnostics, null, null, compilationUnits);
            log.info("数据是:{}"+task);
            boolean success = task.call();

            // 处理编译结果
            if (success) {
                System.out.println("编译成功");
            } else {
                System.out.println("编译失败");
                diagnostics.getDiagnostics().forEach(d -> System.out.format("Line %d, Column %d: %s%n", d.getLineNumber(), d.getColumnNumber(), d.getMessage(null)));
            }

            // 释放资源
            fileManager.close();

        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private static void writeToFile(String fileName, String sourceCode) throws IOException {
        try (FileWriter writer = new FileWriter(fileName)) {
            writer.write(sourceCode);
        }
    }
}
